docs.rs failed to build windows-env-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
windows-env
Easily manage Windows environment variables permanently, without the need to restart your system or terminal.
Features:
- Easily operate list variables like
PATH.
Note:
- The env operation will affect the current terminal process since v0.2.0.
Installation
- as lib:
[] = "0.2.0" - as executable binary:
Example
-
binary usage: runs
wenv -hto see help message. -
lib usage:
Compare
- set_env:
- it uses powershell script while this crate uses windows api
TODO
- cli support
- System env modification
MSRV
- v0.1.1: 1.70