docs.rs failed to build windows-env-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
windows-env
Easily manage Windows environment variables permanently, without the need to restart your system.
Features:
- Concurrent safe.
- Easily operate list variables like
PATH.
Note:
- The env operation will not affect the current terminal.
Installation
- as lib:
[] = "0.1.1" - as executable binary:
Example
lib usage:
executable binary: runs wenv -h to see help message.
Compare
- set_env:
- it uses powershell script while this crate uses windows api
TODO
- cli support
- System env modification